into_write_requests

Function into_write_requests 

pub(crate) fn into_write_requests(
    request: Request,
) -> Result<RemoteWriteV2WriteRequests>
Converts a PRW v2 request into normal sample writes and native histogram writes.

A metric name may appear in only one payload kind per request because the metric-engine logical table is either a float metric or a native histogram.